@@ -1,5 +1,5 @@
 use clipboard::{ClipboardContext, ClipboardProvider};
-use imgui::{ClipboardBackend, ImStr, ImString};
+use imgui::ClipboardBackend;
 
 pub struct ClipboardSupport(ClipboardContext);
 
@@ -8,10 +8,11 @@ pub fn init() -> Option<ClipboardSupport> {
 }
 
 impl ClipboardBackend for ClipboardSupport {
-    fn get(&mut self) -> Option<ImString> {
-        self.0.get_contents().ok().map(|text| text.into())
+    fn get(&mut self) -> Option<String> {
+        self.0.get_contents().ok()
     }
-    fn set(&mut self, text: &ImStr) {
-        let _ = self.0.set_contents(text.to_str().to_owned());
+
+    fn set(&mut self, text: &str) {
+        let _ = self.0.set_contents(text.to_owned());
     }
 }
